schemetools.Scheme
==================

.. inheritance-diagram:: abjad.tools.schemetools.Scheme.Scheme.Scheme
   :private-bases:

.. autoclass:: abjad.tools.schemetools.Scheme.Scheme.Scheme

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.schemetools.Scheme.Scheme.Scheme.force_quotes

.. autoattribute:: abjad.tools.schemetools.Scheme.Scheme.Scheme.lilypond_format

.. autoattribute:: abjad.tools.schemetools.Scheme.Scheme.Scheme.storage_format

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

Special Methods
---------------

.. automethod:: abjad.tools.schemetools.Scheme.Scheme.Scheme.__eq__

.. automethod:: abjad.tools.schemetools.Scheme.Scheme.Scheme.__ge__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.schemetools.Scheme.Scheme.Scheme.__gt__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.schemetools.Scheme.Scheme.Scheme.__le__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.schemetools.Scheme.Scheme.Scheme.__lt__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.schemetools.Scheme.Scheme.Scheme.__ne__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.schemetools.Scheme.Scheme.Scheme.__repr__

.. automethod:: abjad.tools.schemetools.Scheme.Scheme.Scheme.__str__
